==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/content/messages/sv/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(Även synligt för personer som inte är medlemmar i detta forum)',
  '<strong>Confirm</strong> post deletion' => '<strong>Bekräfta</strong> radering av inlägg',
  '<strong>Delete</strong> content?' => '',
  '<strong>Move</strong> content' => '<strong>Flytta</strong> Innehåll',
  '<strong>Permalink</strong> to this post' => '<strong>Permalänk</strong> till det här inlägget',
  'Add a member to notify' => 'Lägg till en medlem som ska notifieras',
  'Add tag...' => 'Lägg till tagg...',
  'Archived' => 'Arkiverad',
  'Attach Files' => 'Bifoga filer',
  'Back to stream' => 'Tillbaka till flöde',
  'Cancel' => 'Avbryt',
  'Cancel Edit' => 'Avbryt ändra',
  'Change to "Private"' => 'Gör privat',
  'Change to "Public"' => 'Gör publik',
  'Comments are locked' => 'Kommentarer är låsta',
  'Comments are unlocked' => 'Kommentarer är olåsta',
  'Confirm' => 'Bekräfta',
  'Content' => 'Innehåll',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Innehållstagg med ogiltigt contentcontainer_id tilldelat.',
  'Content has been moved to {spacename}' => 'Innehållet har flyttat till {spacename}',
  'Content visibility' => 'Innehållets synlighet',
  'Could not delete content!' => 'Kunde inte radera innehåll!',
  'Could not find requested content!' => 'Hittade inte det eftersökta innehållet!',
  'Created at:' => 'Skapad vid:',
  'Created by me' => 'Skapad av mig',
  'Creation time' => 'Skapad',
  'Delete' => 'Ta bort',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Vill du verkligen radera det här inlägget? Alla gillanden samt kommentarer tas bort!',
  'Edit' => 'Ändra',
  'Filter' => 'Filtrera',
  'I\'m involved' => 'Där jag är inblandad',
  'Invalid content id given!' => 'Felaktigt innehålls id angivet!',
  'Invalid request method!' => 'Felaktig anropsmetod!',
  'Invalid space selection.' => 'Felaktigt valt forum.',
  'Last update' => 'Senast uppdaterad',
  'Last updated {time}' => 'Senast uppdaterad {time}',
  'Load more' => 'Ladda mer',
  'Lock comments' => 'Lås kommentarer',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Maximalt antal nålade objekt har uppnåtts! <br> Du kan bara fästa upp till {count} objekt samtidigt.',
  'Move content' => 'Flytta inehåll',
  'Move to archive' => 'Arkivera',
  'New Updates Available!' => '',
  'No matches with your selected filters!' => 'Dina valda filter gav ingen träff!',
  'No tags found for the given query' => 'Inga taggar hittades för den givna frågan',
  'None' => 'Inga',
  'Nothing here yet!' => 'Inget innehåll här ännu!',
  'Notify members' => 'Meddela medlemmar',
  'Permalink' => 'Permalänk',
  'Pin to top' => 'Fäst i toppen',
  'Pinned' => 'Fastnålad',
  'Private' => 'Privat',
  'Public' => 'Publik',
  'Select type...' => 'Välj typ...',
  'Specify who can see this content.' => 'Ange vem som kan se detta innehåll.',
  'Submit' => 'Skicka',
  'Tag' => 'Tagg',
  'Target Space' => 'Målforum',
  'The author of this content is not allowed to create private content within the selected space.' => 'Ägaren till detta innehåll har inte tillåtelse att skapa privat innehåll inom det valda forumet.',
  'The author of this content is not allowed to create public content within the selected space.' => 'Ägaren till detta innehåll har inte tillåtelse att skapa publikt innehåll inom det valda forumet.',
  'The author of this content is not allowed to create this type of content within this space.' => 'Ägaren till detta innehåll har inte tillåtelse att skapa den här typen av innehåll inom det här forumet.',
  'The content can\'t be moved to its current space.' => 'Innehållet kan inte flyttas till sitt nuvarande utrymme.',
  'The content has been archived.' => 'Innehållet har arkiverats.',
  'The content has been deleted.' => 'Innehållet har raderats.',
  'The content has been unarchived.' => 'Innehållet har återställts.',
  'The given name is already in use.' => 'Namnet används redan.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Modulen {moduleName} är inte aktiverad i det valda forumet.',
  'This action is disabled!' => 'Denna åtgärd är inaktiverad!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Den här innehållstypen kan inte flyttas på grund av att en modul-id-inställning saknas.',
  'This content type can\'t be moved.' => 'Den här innehållstypen kan inte flyttas.',
  'This space is archived.' => 'Det här forumet är arkiverat.',
  'This space is not visible!' => 'Forumet är inte synligt!',
  'Topics' => 'Ämnen',
  'Turn off notifications' => 'Slå av notiser',
  'Turn on notifications' => 'Slå på notiser',
  'Unarchive' => 'Återställ',
  'Unlock comments' => 'Lås upp kommentarer',
  'Unpin' => 'Ta bort nål',
  'Updated' => 'Uppdaterad',
  'Visible also to unregistered users' => 'Synlig även för oregistrerade användare',
  'Visible only to you' => 'Synlig endast för dig',
  'Visible to all Space members' => 'Synlig för alla medlemmar i forumet',
  'Visible to all signed in users' => 'Synlig för alla inloggade användare',
  'Visible to friends of {displayName}' => 'Synlig för vänner till {displayName}',
  'Visible to you and {displayName}' => 'Synlig för dig och {displayName}',
  'Visible to your friends' => 'Synlig för dina vänner',
  'With attachments' => 'Med filer som bilagor',
  'You cannot block the space owner!' => 'Du kan inte blockera forumets ägare!',
  'You cannot block the user of the same container!' => 'Du kan inte blockera användaren av samma container!',
  'You cannot block yourself!' => 'Du kan inte blockera dig själv!',
  'You do not have the permission to move this content to the given space.' => 'Du har inte behörighet att flytta detta innehåll till det angivna utrymmet.',
  'You do not have the permission to move this content.' => 'Du har inte behörighet att flytta detta innehåll.',
  'Your last edit state has been saved!' => 'Din senaste redigering har sparats!',
  'in' => 'i',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/content/messages/sv/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(Även synligt för personer som inte är medlemmar i detta forum)',
  '<strong>Confirm</strong> post deletion' => '<strong>Bekräfta</strong> radering av inlägg',
  '<strong>Delete</strong> content?' => '<strong>Ta bort</strong> innehåll?',
  '<strong>Move</strong> content' => '<strong>Flytta</strong> Innehåll',
  '<strong>Permalink</strong> to this post' => '<strong>Permalänk</strong> till det här inlägget',
  'Add a member to notify' => 'Lägg till en medlem som ska notifieras',
  'Add tag...' => 'Lägg till tagg...',
  'Archived' => 'Arkiverad',
  'Attach Files' => 'Bifoga filer',
  'Back to stream' => 'Tillbaka till flöde',
  'Cancel' => 'Avbryt',
  'Cancel Edit' => 'Avbryt ändra',
  'Change to "Private"' => 'Gör privat',
  'Change to "Public"' => 'Gör publik',
  'Comments are locked' => 'Kommentarer är låsta',
  'Comments are unlocked' => 'Kommentarer är olåsta',
  'Confirm' => 'Bekräfta',
  'Content' => 'Innehåll',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Innehållstagg med ogiltigt contentcontainer_id tilldelat.',
  'Content has been moved to {spacename}' => 'Innehållet har flyttat till {spacename}',
  'Content visibility' => 'Innehållets synlighet',
  'Could not delete content!' => 'Kunde inte radera innehåll!',
  'Could not find requested content!' => 'Hittade inte det eftersökta innehållet!',
  'Created at:' => 'Skapad vid:',
  'Created by me' => 'Skapad av mig',
  'Creation time' => 'Skapad',
  'Delete' => 'Ta bort',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Vill du verkligen radera det här inlägget? Alla gillanden samt kommentarer tas bort!',
  'Edit' => 'Ändra',
  'Filter' => 'Filtrera',
  'I\'m involved' => 'Där jag är inblandad',
  'Invalid content id given!' => 'Felaktigt innehålls id angivet!',
  'Invalid request method!' => 'Felaktig anropsmetod!',
  'Invalid space selection.' => 'Felaktigt valt forum.',
  'Last update' => 'Senast uppdaterad',
  'Last updated {time}' => 'Senast uppdaterad {time}',
  'Load more' => 'Ladda mer',
  'Lock comments' => 'Lås kommentarer',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Maximalt antal nålade objekt har uppnåtts! <br> Du kan bara fästa upp till {count} objekt samtidigt.',
  'Move content' => 'Flytta inehåll',
  'Move to archive' => 'Arkivera',
  'New Updates Available!' => 'Nya uppdateringar tillgängliga!',
  'No matches with your selected filters!' => 'Dina valda filter gav ingen träff!',
  'No tags found for the given query' => 'Inga taggar hittades för den givna frågan',
  'None' => 'Inga',
  'Nothing here yet!' => 'Inget innehåll här ännu!',
  'Notify members' => 'Meddela medlemmar',
  'Permalink' => 'Permalänk',
  'Pin to top' => 'Fäst i toppen',
  'Pinned' => 'Fastnålad',
  'Private' => 'Privat',
  'Public' => 'Publik',
  'Select type...' => 'Välj typ...',
  'Specify who can see this content.' => 'Ange vem som kan se detta innehåll.',
  'Submit' => 'Skicka',
  'Tag' => 'Tagg',
  'Target Space' => 'Målforum',
  'The author of this content is not allowed to create private content within the selected space.' => 'Ägaren till detta innehåll har inte tillåtelse att skapa privat innehåll inom det valda forumet.',
  'The author of this content is not allowed to create public content within the selected space.' => 'Ägaren till detta innehåll har inte tillåtelse att skapa publikt innehåll inom det valda forumet.',
  'The author of this content is not allowed to create this type of content within this space.' => 'Ägaren till detta innehåll har inte tillåtelse att skapa den här typen av innehåll inom det här forumet.',
  'The content can\'t be moved to its current space.' => 'Innehållet kan inte flyttas till sitt nuvarande utrymme.',
  'The content has been archived.' => 'Innehållet har arkiverats.',
  'The content has been deleted.' => 'Innehållet har raderats.',
  'The content has been unarchived.' => 'Innehållet har återställts.',
  'The given name is already in use.' => 'Namnet används redan.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Modulen {moduleName} är inte aktiverad i det valda forumet.',
  'This action is disabled!' => 'Denna åtgärd är inaktiverad!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Den här innehållstypen kan inte flyttas på grund av att en modul-id-inställning saknas.',
  'This content type can\'t be moved.' => 'Den här innehållstypen kan inte flyttas.',
  'This space is archived.' => 'Det här forumet är arkiverat.',
  'This space is not visible!' => 'Forumet är inte synligt!',
  'Topics' => 'Ämnen',
  'Turn off notifications' => 'Slå av notiser',
  'Turn on notifications' => 'Slå på notiser',
  'Unarchive' => 'Återställ',
  'Unlock comments' => 'Lås upp kommentarer',
  'Unpin' => 'Ta bort nål',
  'Updated' => 'Uppdaterad',
  'Visible also to unregistered users' => 'Synlig även för oregistrerade användare',
  'Visible only to you' => 'Synlig endast för dig',
  'Visible to all Space members' => 'Synlig för alla medlemmar i forumet',
  'Visible to all signed in users' => 'Synlig för alla inloggade användare',
  'Visible to friends of {displayName}' => 'Synlig för vänner till {displayName}',
  'Visible to you and {displayName}' => 'Synlig för dig och {displayName}',
  'Visible to your friends' => 'Synlig för dina vänner',
  'With attachments' => 'Med filer som bilagor',
  'You cannot block the space owner!' => 'Du kan inte blockera forumets ägare!',
  'You cannot block the user of the same container!' => 'Du kan inte blockera användaren av samma container!',
  'You cannot block yourself!' => 'Du kan inte blockera dig själv!',
  'You do not have the permission to move this content to the given space.' => 'Du har inte behörighet att flytta detta innehåll till det angivna utrymmet.',
  'You do not have the permission to move this content.' => 'Du har inte behörighet att flytta detta innehåll.',
  'Your last edit state has been saved!' => 'Din senaste redigering har sparats!',
  'in' => 'i',
);
